Template Tags
=============

**************
Inclusion Tags
**************

.. automodule:: tom_targets.templatetags.targets_extras
    :members: recent_targets, target_feature, target_data, target_groups, target_plan, target_distribution, select_target_js, aladin

*******
Filters
*******

.. automodule:: tom_targets.templatetags.targets_extras
    :members: deg_to_sexigesimal, target_extra_field
    :noindex: